.. :changelog:

History
-------
0.1.3 (2014-03-10)
++++++++++++++++++

* Add exception logging if URL generation fails

0.1.2 (2014-03-07)
++++++++++++++++++

* Remove utils (lock, memoizer)
* Monkeypatch ReadBuffer to add open() stub (fixes issue with easy_thumbnails)

0.1.1 (2013-10-10)
++++++++++++++++++

* Fix for distributed lock

0.1.0 (2013-08-15)
++++++++++++++++++

* First release on PyPI.